Index: uspace/lib/nettl/src/amap.c
===================================================================
--- uspace/lib/nettl/src/amap.c	(revision b10460aa6a666f2289836624216d445ff03a7816)
+++ uspace/lib/nettl/src/amap.c	(revision 8a637a47d260c9852eb7bbefc705cba01e8ef051)
@@ -349,5 +349,5 @@
  * @param aepp Place to store actual endpoint pair, possibly with allocated port
  *
- * @return EOK on success, EEXISTS if conflicting epp exists,
+ * @return EOK on success, EEXIST if conflicting epp exists,
  *         ENOMEM if out of memory
  */
@@ -394,5 +394,5 @@
  * @param aepp Place to store actual endpoint pair, possibly with allocated port
  *
- * @return EOK on success, EEXISTS if conflicting epp exists,
+ * @return EOK on success, EEXIST if conflicting epp exists,
  *         ENOMEM if out of memory
  */
@@ -438,5 +438,5 @@
  * @param aepp Place to store actual endpoint pair, possibly with allocated port
  *
- * @return EOK on success, EEXISTS if conflicting epp exists,
+ * @return EOK on success, EEXIST if conflicting epp exists,
  *         ENOMEM if out of memory
  */
@@ -482,5 +482,5 @@
  * @param aepp Place to store actual endpoint pair, possibly with allocated port
  *
- * @return EOK on success, EEXISTS if conflicting epp exists,
+ * @return EOK on success, EEXIST if conflicting epp exists,
  *         ENOMEM if out of memory
  */
@@ -515,5 +515,5 @@
  * @param aepp Place to store actual endpoint pair, possibly with allocated port
  *
- * @return EOK on success, EEXISTS if conflicting epp exists,
+ * @return EOK on success, EEXIST if conflicting epp exists,
  *         ENOMEM if out of memory
  */
Index: uspace/lib/nettl/src/portrng.c
===================================================================
--- uspace/lib/nettl/src/portrng.c	(revision b10460aa6a666f2289836624216d445ff03a7816)
+++ uspace/lib/nettl/src/portrng.c	(revision 8a637a47d260c9852eb7bbefc705cba01e8ef051)
@@ -88,5 +88,5 @@
  * @param apnum Place to store allocated port number
  *
  * @return EOK on success, ENOENT if no free port number found, EEXISTS
  *         if @a pnum is specified but it is already allocated,
  *         EINVAL if @a pnum is specified from the system range, but
@@ -137,5 +137,5 @@
 			if (port->pn == pnum) {
 				log_msg(LOG_DEFAULT, LVL_DEBUG2, "port already used");
-				return EEXISTS;
+				return EEXIST;
 			}
 		}
@@ -88,5 +88,5 @@
  * @param apnum Place to store allocated port number
  *
- * @return EOK on success, ENOENT if no free port number found, EEXISTS
+ * @return EOK on success, ENOENT if no free port number found, EEXIST
  *         if @a pnum is specified but it is already allocated,
  *         EINVAL if @a pnum is specified from the system range, but
